@@ -1,15 +1,16 @@
 """
 Simple example using TOON with files (load/dump)
 """
+
 import toons
 
 # Data to save
 data = {
     "users": [
         {"name": "Alice", "role": "admin"},
-        {"name": "Bob", "role": "user"}
+        {"name": "Bob", "role": "user"},
     ],
-    "active": True
+    "active": True,
 }
 
 # Write TOON data to file
