@@ -1,14 +1,11 @@
 """
 Simple example using TOON with strings (loads/dumps)
 """
+
 import toons
 
 # Serialize Python dict to TOON string
-data = {
-    "name": "Alice",
-    "age": 30,
-    "tags": ["python", "rust", "toon"]
-}
+data = {"name": "Alice", "age": 30, "tags": ["python", "rust", "toon"]}
 
 toon_string = toons.dumps(data)
 print("TOON output:")
